/*
  $Id: 8x16.c,v 1.1 2016/08/11 17:55:59 ewan Exp $
  Convert font data from graphical image format into OLED page format.
  8x16.c (C) 2016 Ewan Parker.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

  The author may be reached at http//www.ewan.cc/ for queries.
*/

#include "8x16.h"
#include <stdio.h>

// Initial and final character positions in the image file.
#define START 0
#define FINISH 127

void process_char(char ch) {
  // Convert the ImageMagick H file into a grid of 0s and 1s, and invert.
  short matrix[128]; int o = 0;
  printf("  // Character: 0x%.2X %.3d\n", ch, ch);
  unsigned short b;
  short p;
  for (p = 0; p < 16; p++) {
    b = ~MagickImage[11 + ch%16 + (ch >> 4) * 256 + 16 * p];
    short i;
    for (i = 7; i >= 0; i--) matrix[o++] = ((b >> i) & 1);
  }

  // Visual representations (for human information only).
  char old[16], new[16];
  for (p = 1; p <= 13; p += 2) {
    old[p] = ' '; new[p] = ' ';
  }
  old[15] = 0; new[15] = 0;

  // Translate the character grid into page data for the OLED display.
  int n;
  p = 0;
  for (o = 0; o < 128; o++) {
    n = ((0x7-o)&0x07)*8+(o>>3)+((o&0x40)>>6)*56;
    p = (p << 1) | matrix[n];
    old[(o%0x08) * 2]=matrix[o]*('#'-'.')+'.';
    new[(o%0x08) * 2]=matrix[n]*('#'-'.')+'.';
    if (o%8==7) {
      printf("  /* %s */  0x%.2X,  // %s\n", old, p, new);
      p = 0;
    }
  }
}

int main(void) {
  printf("#include <avr/pgmspace.h>\n\n");
  printf("const uint8_t bmap8x16[] PROGMEM = {\n");
  short x;
  for (x = START; x <= FINISH; x++) process_char(x);
  printf("};\n");
  return 0;
}
