/*
  $Id: ScrollCharacterSet.ino,v 1.1 2016/08/11 17:55:59 ewan Exp $
  Show the entire character set on the OLED display, in a scrolling fashion.
  ScrollCharacterSet.ino (C) 2016 Ewan Parker.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

  The author may be reached at http//www.ewan.cc/ for queries.


  The assumption is that the SSD1306 driven 128x32 OLED display is connected to
  the Arduino Uno via I2C, thus.

  Arduino Uno       128x32 SSD1306 OLED
  ============      ===================
  GND          ---> GND
  5V           ---> VCC
  A5 (I2C SCL) ---> SCK
  A4 (I2C SDA) ---> SDA
*/

// Uncomment the following line to use this example sketch with an LCD
// library.  Its output can be compared side-by-side with the OLED's.
//#define USELCD 1

// Co-ordinates.
short x = 0, y = 0;

#ifdef USELCD
#include <Wire.h>
#include <LiquidCrystal_I2C.h>
#define FIRST ' '
#define LAST 126
//                    addr, en,rw,rs,d4,d5,d6,d7,bl,blpol
LiquidCrystal_I2C disp(0x27, 2, 1, 0, 4, 5, 6, 7, 3, POSITIVE);  // Set the LCD I2C address
#else
#include <SSD1306I2C1602.h>
#define FIRST 0
#define LAST 126
SSD1306I2C1602 disp; // Set the address for the OLED display.
#endif

uint8_t start = FIRST;

void setup()
{
  disp.begin(16,2); // Initialise the display for 16 chars 2 lines
  disp.backlight(); // and turn on backlight
}

void loop()
{
  char c;

  // Display the top line.
  x = 0; y = 0;
  disp.setCursor(x, y);
  for (c = start; c < start + 16; c++)
    disp.print(c);

  // Display the bottom line.
  y++;
  disp.setCursor(x, y);
  for (c = start + 16; c < start + 32; c++)
    disp.print(c);

  // Check if we are at the end of the alphabet.
  if (start == FIRST) delay(1800);
  delay(200);
  if (++start == LAST - 30)
  {
    delay(1800);
    start = FIRST;
  }
}
